@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_events._jsii
 import aws_cdk.aws_iam._jsii
@@ -16,7 +16,7 @@ import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-cdk/aws-config", "1.63.0", __name__[0:-6], "aws-config@1.63.0.jsii.tgz"
+    "@aws-cdk/aws-config", "1.64.0", __name__[0:-6], "aws-config@1.64.0.jsii.tgz"
 )
 
 __all__ = [
